@@ -1,5 +1,5 @@
 /*
- *   $Id: interface.c,v 1.1 1996/12/21 18:04:20 lf Exp $
+ *   $Id: interface.c,v 1.2 1997/01/05 19:17:41 lf Exp $
  *
  *   Authors:
  *    Lars Fenneberg		<lf@elemental.net>	 
@@ -13,6 +13,8 @@
  *
  */
 
+#include "config.h"
+
 #include <syslog.h>
 #include <string.h>
 
@@ -74,14 +76,14 @@ check_iface(struct Interface *iface)
 		res = -1;
 	}
 
-	if (iface->dev->mtu_max != -1)
+	if (iface->if_maxmtu != -1)
 	{
 		if ((iface->AdvLinkMTU != 0) &&
 		   ((iface->AdvLinkMTU < MIN_AdvLinkMTU) || 
-		   (iface->AdvLinkMTU > iface->dev->mtu_max)))
+		   (iface->AdvLinkMTU > iface->if_maxmtu)))
 		{
 			log(LOG_ERR,  "AdvLinkMTU must be zero or between %d and %d for %s",
-			MIN_AdvLinkMTU, iface->dev->mtu_max, iface->Name);
+			MIN_AdvLinkMTU, iface->if_maxmtu, iface->Name);
 			res = -1;
 		}
 	}
