@@ -1,5 +1,5 @@
 /*
- *	$Id: log.c,v 1.3 1996/12/21 18:04:20 lf Exp $
+ *	$Id: log.c,v 1.4 1997/01/05 19:17:41 lf Exp $
  *
  *	Authors:
  *	 Lars Fenneberg		<lf@elemental.net>	 
@@ -13,11 +13,14 @@
  *
  */
 
+#include "config.h"
+
 #include <stdio.h>
 #include <stdarg.h>
 #include <stdlib.h>
 #include <time.h>
 #include <syslog.h>
+#include <errno.h>	/* on the Alpha/glibc stdlib.h doesn't include errno.h */
 
 #define TIME_FORMAT "%b %d %H:%M:%S"
 
