@@ -1,5 +1,5 @@
 /*
- *   $Id: radvd.c,v 1.4 1996/12/21 18:04:20 lf Exp $
+ *   $Id: radvd.c,v 1.6 1997/01/16 21:14:38 lf Exp $
  *
  *   Authors:
  *    Pedro Roque		<roque@di.fc.ul.pt>
@@ -14,16 +14,21 @@
  *
  */
 
+#include "config.h"
+
 #include <stdio.h>
 #include <errno.h>
 #include <unistd.h>
-#include <getopt.h>
 #include <string.h>
 #include <signal.h>
 #include <syslog.h>
 #include <stdlib.h>
 #include <time.h>
 
+#ifdef HAVE_GETOPT_H
+#include <getopt.h>
+#endif
+
 #include <sys/types.h>
 
 #include "radvd.h"
@@ -35,6 +40,7 @@ char usage_str[] =
 	"[-vh] [-d level] [-C config_file] [-m log_method] [-l log_file]\n"
 	"\t[-f facility]";
 
+#ifdef HAVE_GETOPT_LONG
 struct option prog_opt[] = {
 	{"debug", 1, 0, 'd'},
 	{"config", 1, 0, 'C'},
@@ -45,6 +51,7 @@ struct option prog_opt[] = {
 	{"help", 0, 0, 'h'},
 	{NULL, 0, 0, 0}
 };
+#endif
 
 extern FILE *yyin;
 
@@ -63,10 +70,12 @@ main(int argc, char *argv[])
 {
 	unsigned char msg[MSG_SIZE];
 	struct Interface *iface;
-	int opt_idx;
 	int c, log_method;
 	char *logfile;
 	int facility;
+#ifdef HAVE_GETOPT_LONG
+	int opt_idx;
+#endif
 
 	pname = ((pname=strrchr(argv[0],'/')) != NULL)?pname+1:argv[0];
 
@@ -78,7 +87,11 @@ main(int argc, char *argv[])
 	facility = LOG_FACILITY;
 
 	/* parse args */
+#ifdef HAVE_GETOPT_LONG
 	while ((c = getopt_long(argc, argv, "d:C:l:m:vh", prog_opt, &opt_idx)) > 0)
+#else
+	while ((c = getopt(argc, argv, "d:C:l:m:vh")) > 0)
+#endif
 	{
 		switch (c) {
 		case 'C':
@@ -121,10 +134,12 @@ main(int argc, char *argv[])
 			break;
 		case 'h':
 			usage();
+#ifdef HAVE_GETOPT_LONG
 		case ':':
 			fprintf(stderr, "%s: option %s: parameter expected\n", pname,
 				prog_opt[opt_idx].name);
 			exit(1);
+#endif
 		case '?':
 			exit(1);
 		}
@@ -204,14 +219,14 @@ main(int argc, char *argv[])
 
 	for (;;)
 	{
-		int len;
+		int len, hoplimit;
 		struct sockaddr_in6 rcv_addr;
 		struct in6_pktinfo *pkt_info = NULL;
 		
-		len = recv_rs(sock, msg, &rcv_addr, &pkt_info);
+		len = recv_rs_ra(sock, msg, &rcv_addr, &pkt_info, &hoplimit);
 		if (len > 0)
 			process(sock, IfaceList, msg, len, 
-				&rcv_addr, pkt_info);
+				&rcv_addr, pkt_info, hoplimit);
 	}
 }
 
