@@ -1,5 +1,5 @@
 /*
- *   $Id: radvd.h,v 1.3 1996/12/21 18:04:20 lf Exp $
+ *   $Id: radvd.h,v 1.9 1997/01/19 17:11:29 lf Exp $
  *
  *   Authors:
  *    Pedro Roque		<roque@di.fc.ul.pt>
@@ -17,21 +17,15 @@
 #ifndef RADV_H
 #define RADV_H
 
+#include "config.h"
+
 #include <unistd.h>
+#include <sys/socket.h>
 #include <netinet/in.h>
 #include <netinet6/in6.h>
 #include <netinet6/ipv6.h>
 #include <net/if.h>
 
-/* older kernels don't define IPV6_CHECKSUM but RAW_CHECKSUM */
-#ifndef IPV6_CHECKSUM
-#define IPV6_CHECKSUM RAW_CHECKSUM
-#endif
-
-#ifndef IPV6_ADDR_LINKLOCAL 
-#define IPV6_ADDR_LINKLOCAL   0x0020U
-#endif
-
 /* protocol constants as specified by RFC 1970 */
 #define MAX_INITIAL_RTR_ADVERT_INTERVAL	       16 /* seconds */
 #define MAX_INITIAL_RTR_ADVERTISEMENTS		3 /* transmissions */
@@ -57,7 +51,8 @@ struct timer_lst {
 };
 
 struct AdvPrefix;
-struct Device;
+
+#define HWADDR_MAX 16
 
 struct Interface {
 	char			Name[IFNAMSIZ+1];	/* interface name */
@@ -65,8 +60,9 @@ struct Interface {
 	struct in6_addr		if_addr;
 	int			if_index;
 
-	struct Device		*dev;
-	struct sockaddr		if_hwaddr;
+	u_int8_t		if_hwaddr[HWADDR_MAX];
+	int			if_tokenlen;
+	int			if_maxmtu;
 
 	int			AdvSendAdvert;
 	int			MaxRtrAdvInterval;
@@ -92,19 +88,12 @@ struct AdvPrefix {
 	
 	int			AdvOnLinkFlag;
 	int			AdvAutonomousFlag;
-	__u32			AdvValidLifetime;
-	__u32			AdvPreferredLifetime;
+	u_int32_t		AdvValidLifetime;
+	u_int32_t		AdvPreferredLifetime;
 
 	struct AdvPrefix	*next;
 };
 
-struct Device {
-	int ifhwtype;
-	int tokenlen;
-	int mtu_max;
-	int (*fillin_hwaddr)(struct Interface *, void *);
-};
-
 /* gram.y */
 int yyparse(void);
 
@@ -128,15 +117,13 @@ int get_debuglevel(void);
 /* device.c */
 int setup_deviceinfo(int sock, struct Interface *);
 int check_device(int sock, struct Interface *);
+int setup_linklocal_addr(int sock, struct Interface *);
 
 /* interface.c */
 void iface_init_defaults(struct Interface *);
 void prefix_init_defaults(struct AdvPrefix *);
 int check_iface(struct Interface *);
 
-/* linklocal.c */
-int setup_linklocal_addr(struct Interface *);
-
 /* socket.c */
 int open_icmpv6_socket(void);
 
@@ -145,10 +132,10 @@ void send_ra(int, struct Interface *iface, struct in6_addr *dest);
 
 /* process.c */
 void process(int sock, struct Interface *, unsigned char *, int,
-	struct sockaddr_in6 *, struct in6_pktinfo *);
+	struct sockaddr_in6 *, struct in6_pktinfo *, int);
 
 /* recv.c */
-int recv_rs(int, char *, struct sockaddr_in6 *, struct in6_pktinfo **);
+int recv_rs_ra(int, char *, struct sockaddr_in6 *, struct in6_pktinfo **, int *);
 
 /* util.c */
 void mdelay(int);
