@@ -1,5 +1,5 @@
 /*
- *   $Id: radvdump.c,v 1.1 1996/12/21 18:04:20 lf Exp $
+ *   $Id: radvdump.c,v 1.4 1997/01/16 21:14:38 lf Exp $
  *
  *   Authors:
  *    Lars Fenneberg		<lf@elemental.net>	 
@@ -13,51 +13,66 @@
  *
  */
 
+#include "config.h"
+
 #include <stdio.h>
 #include <errno.h>
 #include <unistd.h>
-#include <getopt.h>
 #include <string.h>
 #include <signal.h>
 #include <syslog.h>
 #include <stdlib.h>
 #include <time.h>
 
+#include <sys/types.h>
+#include <sys/socket.h>
 #include <netinet6/in6.h>
 #include <netinet6/nd6_protocol.h>
-#include <sys/types.h>
+
+#ifdef HAVE_GETOPT_H
+#include <getopt.h>
+#endif
 
 #include "radvd.h"
 #include "pathnames.h"
 
 char usage_str[] = "[-vh] [-d level]";
 
+#ifdef HAVE_GETOPT_LONG
 struct option prog_opt[] = {
 	{"debug", 1, 0, 'd'},
 	{"version", 0, 0, 'v'},
 	{"help", 0, 0, 'h'},
 	{NULL, 0, 0, 0}
 };
+#endif
 
 char *pname;
 int sock = -1;
 
 void version(void);
 void usage(void);
-void print_ra(unsigned char *, int, struct sockaddr_in6 *);
+void print_ra(unsigned char *, int, struct sockaddr_in6 *, int);
 
 int
 main(int argc, char *argv[])
 {
 	unsigned char msg[MSG_SIZE];
-	int opt_idx, c, len;
+	int c, len, hoplimit;
 	struct sockaddr_in6 rcv_addr;
         struct in6_pktinfo *pkt_info = NULL;
+#ifdef HAVE_GETOPT_LONG
+	int opt_idx;
+#endif
 
 	pname = ((pname=strrchr(argv[0],'/')) != NULL)?pname+1:argv[0];
 
 	/* parse args */
-	while ((c = getopt_long(argc, argv, "d:C:l:m:vh", prog_opt, &opt_idx)) > 0)
+#ifdef HAVE_GETOPT_LONG
+	while ((c = getopt_long(argc, argv, "d:hv", prog_opt, &opt_idx)) > 0)
+#else
+	while ((c = getopt(argc, argv, "d:hv")) > 0)
+#endif
 	{
 		switch (c) {
 		case 'd':
@@ -68,10 +83,12 @@ main(int argc, char *argv[])
 			break;
 		case 'h':
 			usage();
+#ifdef HAVE_GETOPT_LONG
 		case ':':
 			fprintf(stderr, "%s: option %s: parameter expected\n", pname,
 				prog_opt[opt_idx].name);
 			exit(1);
+#endif
 		case '?':
 			exit(1);
 		}
@@ -87,7 +104,7 @@ main(int argc, char *argv[])
 		
 	for(;;)
 	{
-	        len = recv_rs(sock, msg, &rcv_addr, &pkt_info);
+	        len = recv_rs_ra(sock, msg, &rcv_addr, &pkt_info, &hoplimit);
    	     	if (len > 0)
        	 	{
 			struct icmpv6hdr *icmph;
@@ -123,7 +140,7 @@ main(int argc, char *argv[])
 			}
 			else if (icmph->icmpv6_type == ND6_ROUTER_ADVERTISEMENT)
 			{
-				print_ra(msg, len, &rcv_addr);
+				print_ra(msg, len, &rcv_addr, hoplimit);
 			}
         	}
        		 else if (len == 0)
@@ -142,15 +159,35 @@ main(int argc, char *argv[])
 }
 
 void
-print_ra(unsigned char *msg, int len, struct sockaddr_in6 *addr)
+print_ra(unsigned char *msg, int len, struct sockaddr_in6 *addr, int hoplimit)
 {
 	struct nd_router_advert *radvert;
 	char addr_str[INET6_ADDRSTRLEN];
 	u_int8_t *opt_str;
 	int i;
 
+	if (get_debuglevel() > 2)
+	{
+		int j;
+		char hd[64];
+		
+		dlog(LOG_DEBUG, 3, "Hexdump of packet (length %d):", len);
+		
+		for (j = 0; j < len; j++)
+		{
+			sprintf(hd+3*(j%16), "%02X ", (unsigned int) msg[j]);
+				
+			if (!((j+1)%16) || (j+1) == len)
+			{
+				dlog(LOG_DEBUG, 3, hd);
+			}
+		}
+		
+		dlog(LOG_DEBUG, 4, "Hexdump printed");
+	}
+
 	print_addr(&addr->sin6_addr, addr_str);
-	printf("Router advertisement from %s\n", addr_str);
+	printf("Router advertisement from %s (hoplimit %d)\n", addr_str, hoplimit);
 
 	radvert = (struct nd_router_advert *) msg;
 
@@ -189,6 +226,9 @@ print_ra(unsigned char *msg, int len, struct sockaddr_in6 *addr)
 		
 		optlen = (opt_str[1] << 3);
 
+		dlog(LOG_DEBUG,4, "option type %d, length %d", (int)*opt_str,
+			optlen);
+
 		if (optlen == 0) 
 		{
 			log(LOG_ERR, "zero length option in RA");
@@ -197,7 +237,8 @@ print_ra(unsigned char *msg, int len, struct sockaddr_in6 *addr)
 		else if (optlen > len)
 		{
 			log(LOG_ERR, "option length greater than total"
-				" length in RA");
+				" length in RA (type %d, optlen %d, len %d)", 
+				(int)*opt_str, optlen, len);
 			break;
 		} 		
 
