@@ -1,5 +1,5 @@
 /*
- *   $Id: send.c,v 1.3 1996/12/21 18:04:20 lf Exp $
+ *   $Id: send.c,v 1.5 1997/01/07 22:16:57 lf Exp $
  *
  *   Authors:
  *    Pedro Roque		<roque@di.fc.ul.pt>
@@ -14,12 +14,15 @@
  *
  */
 
+#include "config.h"
+
 #include <syslog.h>
 #include <string.h>
 #include <errno.h>
 
 #include <sys/types.h>
 #include <sys/time.h>
+#include <sys/uio.h>
 #include <netinet/in.h>
 #include <netinet6/in6.h>
 #include <netinet6/nd6_protocol.h>
@@ -29,10 +32,7 @@
 void
 send_ra(int sock, struct Interface *iface, struct in6_addr *dest)
 {
-	const struct in6_addr all_hosts_addr = {{{
-		0xFF, 0x02, 0, 0, 0, 0, 0, 0,
-		0, 0, 0, 0, 0, 0, 0, 1
-	}}};
+	u_int8_t all_hosts_addr[] = {0xff,0x02,0,0,0,0,0,0,0,0,0,0,0,0,0,1};
 	struct sockaddr_in6 addr;
 	struct in6_pktinfo *pkt_info;
 	struct msghdr mhdr;
@@ -51,7 +51,7 @@ send_ra(int sock, struct Interface *iface, struct in6_addr *dest)
 	{
 		struct timeval tv;
 
-		dest = &all_hosts_addr;
+		dest = (struct in6_addr *)all_hosts_addr;
 		gettimeofday(&tv, NULL);
 
 		iface->last_multicast = tv.tv_sec;
@@ -131,20 +131,21 @@ send_ra(int sock, struct Interface *iface, struct in6_addr *dest)
 	 * add Source Link-layer Address option
 	 */
 
-	if (iface->AdvSourceLLAddress && iface->dev->fillin_hwaddr)
+	if (iface->AdvSourceLLAddress && iface->if_tokenlen != -1)
 	{
-		void *hwaddr;
 		u_int8_t *ucp;
+		int i;
 
 		ucp = (u_int8_t *) (buff + len);
 	
 		*ucp++  = ND6_OPT_SOURCE_LINKADDR;
-		*ucp++  = (u_int8_t) ((iface->dev->tokenlen + 16 + 63) >> 6);
+		*ucp++  = (u_int8_t) ((iface->if_tokenlen + 16 + 63) >> 6);
 
 		len += 2 * sizeof(u_int8_t);
 
-		hwaddr = (void *) (buff + len);
-		len += iface->dev->fillin_hwaddr(iface, hwaddr);
+		i = (iface->if_tokenlen + 7) >> 3;
+		memcpy(buff + len, iface->if_hwaddr, i);
+		len += i;
 	}
 
 	iov.iov_len  = len;
@@ -154,15 +155,15 @@ send_ra(int sock, struct Interface *iface, struct in6_addr *dest)
 	
 	cmsg->cmsg_len   = (sizeof(struct cmsghdr) +
 			    sizeof(struct in6_pktinfo));
-	cmsg->cmsg_level = SOL_IPV6;
+	cmsg->cmsg_level = IPPROTO_IPV6;
 	cmsg->cmsg_type  = IPV6_TXINFO;
 	
-	pkt_info = (struct in6_pktinfo *) cmsg->cmsg_data;
+	pkt_info = (struct in6_pktinfo *)((void *)cmsg + sizeof(struct cmsghdr));
 	memset(pkt_info, 0, sizeof(struct in6_pktinfo));
 	pkt_info->ipi6_ifindex = iface->if_index;
 	memcpy(&pkt_info->ipi6_addr, &iface->if_addr, sizeof(struct in6_addr));
 
-	mhdr.msg_name = &addr;
+	mhdr.msg_name = (caddr_t)&addr;
 	mhdr.msg_namelen = sizeof(struct sockaddr_in6);
 	mhdr.msg_iov = &iov;
 	mhdr.msg_iovlen = 1;
