@@ -1,5 +1,5 @@
 /*
- *   $Id: util.c,v 1.1 1996/12/21 18:04:20 lf Exp $
+ *   $Id: util.c,v 1.5 1997/01/16 21:14:38 lf Exp $
  *
  *   Authors:
  *    Lars Fenneberg		<lf@elemental.net>	 
@@ -13,11 +13,15 @@
  *
  */
 
+#include "config.h"
+
 #include <sys/time.h>
 #include <sys/types.h>
 #include <stdlib.h>
 #include <unistd.h>
+#include <netdb.h>
 
+#include <sys/socket.h>
 #include <netinet6/in6.h>
 
 #include "radvd.h"
@@ -42,9 +46,9 @@ rand_between(int lower, int upper)
 void
 print_addr(struct in6_addr *addr, char *str)
 {
-	char *res;
+	const char *res;
 
-	res =  inet_ntop(AF_INET6, (void *)addr, str, INET6_ADDRSTRLEN);
+	res = inet_ntop(AF_INET6, (void *)addr, str, INET6_ADDRSTRLEN);
 	
 	if (res == NULL) 
 	{
